@@ -24,7 +24,6 @@ describe 'neutron::agents::metering' do
 
   let :pre_condition do
     "class { 'neutron':
-      rabbit_password => 'passw0rd',
       service_plugins => ['neutron.services.metering.metering_plugin.MeteringPlugin'] }"
   end
 
@@ -35,7 +34,6 @@ describe 'neutron::agents::metering' do
   let :default_params do
     { :package_ensure   => 'present',
       :enabled          => true,
-      :debug            => false,
       :interface_driver => 'neutron.agent.linux.interface.OVSInterfaceDriver',
       :driver           => 'neutron.services.metering.drivers.noop.noop_driver.NoopMeteringDriver',
       :purge_config     => false,
@@ -62,7 +60,7 @@ describe 'neutron::agents::metering' do
     end
 
     it 'configures metering_agent.ini' do
-      is_expected.to contain_neutron_metering_agent_config('DEFAULT/debug').with_value(p[:debug]);
+      is_expected.to contain_neutron_metering_agent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_metering_agent_config('DEFAULT/interface_driver').with_value(p[:interface_driver]);
       is_expected.to contain_neutron_metering_agent_config('DEFAULT/driver').with_value(p[:driver]);
       is_expected.to contain_neutron_metering_agent_config('DEFAULT/measure_interval').with_value('<SERVICE DEFAULT>');
@@ -76,7 +74,8 @@ describe 'neutron::agents::metering' do
           :ensure => p[:package_ensure],
           :tag    => ['openstack', 'neutron-package'],
         )
-        is_expected.to contain_package('neutron').with_before(/Package\[neutron-metering-agent\]/)
+        is_expected.to contain_package('neutron').that_requires('Anchor[neutron::install::begin]')
+        is_expected.to contain_package('neutron').that_notifies('Anchor[neutron::install::end]')
       end
     end
 
@@ -85,10 +84,10 @@ describe 'neutron::agents::metering' do
         :name    => platform_params[:metering_agent_service],
         :enable  => true,
         :ensure  => 'running',
-        :require => 'Class[Neutron]',
         :tag     => 'neutron-service',
       )
-      is_expected.to contain_service('neutron-metering-service').that_subscribes_to('Package[neutron]')
+      is_expected.to contain_service('neutron-metering-service').that_subscribes_to('Anchor[neutron::service::begin]')
+      is_expected.to contain_service('neutron-metering-service').that_notifies('Anchor[neutron::service::end]')
     end
 
     context 'with manage_service as false' do
@@ -124,7 +123,8 @@ describe 'neutron::agents::metering' do
 
     it_configures 'neutron metering agent'
     it 'configures subscription to neutron-metering-agent package' do
-      is_expected.to contain_service('neutron-metering-service').that_subscribes_to('Package[neutron-metering-agent]')
+      is_expected.to contain_service('neutron-metering-service').that_subscribes_to('Anchor[neutron::service::begin]')
+      is_expected.to contain_service('neutron-metering-service').that_notifies('Anchor[neutron::service::end]')
     end
   end
 
