@@ -3,15 +3,13 @@ require 'spec_helper'
 describe 'neutron::agents::ml2::sriov' do
 
   let :pre_condition do
-    "class { 'neutron': rabbit_password => 'passw0rd' }"
+    "class { 'neutron': }"
   end
 
   let :default_params do
     { :package_ensure             => 'present',
       :enabled                    => true,
       :manage_service             => true,
-      :physical_device_mappings   => [],
-      :exclude_devices            => [],
       :polling_interval           => 2,
       :supported_pci_vendor_devs  => [],
       :purge_config               => false,
@@ -43,12 +41,15 @@ describe 'neutron::agents::ml2::sriov' do
 
     it 'configures /etc/neutron/plugins/ml2/sriov_agent.ini' do
       is_expected.to contain_neutron_sriov_agent_config('sriov_nic/polling_interval').with_value(p[:polling_interval])
-      is_expected.to contain_neutron_sriov_agent_config('sriov_nic/exclude_devices').with_value(p[:exclude_devices].join(','))
-      is_expected.to contain_neutron_sriov_agent_config('sriov_nic/physical_device_mappings').with_value(p[:physical_device_mappings].join(','))
+      is_expected.to contain_neutron_sriov_agent_config('sriov_nic/exclude_devices').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_sriov_agent_config('sriov_nic/physical_device_mappings').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_sriov_agent_config('agent/extensions').with_value(['<SERVICE DEFAULT>'])
+      is_expected.to contain_neutron_sriov_agent_config('securitygroup/firewall_driver').with_value('noop')
     end
 
-
+    it 'does not configure numvfs by default' do
+      is_expected.not_to contain_neutron_agents_ml2_sriov_numvfs('<SERVICE DEFAULT>')
+    end
 
     it 'installs neutron sriov-nic agent package' do
       is_expected.to contain_package('neutron-sriov-nic-agent').with(
@@ -71,6 +72,27 @@ describe 'neutron::agents::ml2::sriov' do
       is_expected.to contain_service('neutron-sriov-nic-agent-service').that_notifies('Anchor[neutron::service::end]')
     end
 
+    context 'when number_of_vfs is empty' do
+      before :each do
+        params.merge!(:number_of_vfs => "")
+      end
+
+      it 'does not configure numvfs ' do
+        is_expected.not_to contain_neutron_agents_ml2_sriov_numvfs('<SERVICE DEFAULT>')
+      end
+    end
+
+    context 'when number_of_vfs is configured' do
+      before :each do
+        params.merge!(:number_of_vfs => ['eth0:4','eth1:5'])
+      end
+
+      it 'configures numvfs' do
+        is_expected.to contain_neutron_agent_sriov_numvfs('eth0:4').with( :ensure => 'present' )
+        is_expected.to contain_neutron_agent_sriov_numvfs('eth1:5').with( :ensure => 'present')
+      end
+    end
+
     context 'with manage_service as false' do
       before :each do
         params.merge!(:manage_service => false)
@@ -92,6 +114,18 @@ describe 'neutron::agents::ml2::sriov' do
       end
     end
 
+    context 'when supplying empty device mapping' do
+      before :each do
+        params.merge!(:physical_device_mappings => "",
+                      :exclude_devices          => "")
+      end
+
+      it 'configures physical device mappings with exclusion' do
+        is_expected.to contain_neutron_sriov_agent_config('sriov_nic/exclude_devices').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_neutron_sriov_agent_config('sriov_nic/physical_device_mappings').with_value('<SERVICE DEFAULT>')
+      end
+    end
+
     context 'when supplying extensions for ML2 SR-IOV agent' do
       before :each do
         params.merge!(:extensions => ['qos'])
