@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'neutron::agents::ovn_metadata' do
 
   let :pre_condition do
-    "class { 'neutron': rabbit_password => 'passw0rd' }"
+    "class { 'neutron': }"
   end
 
   let :params do
@@ -118,7 +118,7 @@ describe 'neutron::agents::ovn_metadata' do
     end
 
     let :platform_params do
-      { :ovn_metadata_agent_package => 'networking-ovn-metadata-agent',
+      { :ovn_metadata_agent_package => 'python-networking-ovn-metadata-agent',
         :ovn_metadata_agent_service => 'networking-ovn-metadata-agent' }
     end
 
